@@ -1,4 +1,4 @@
-__version__ = '0.0.6'
+__version__ = '0.0.8'
 
 from gevent import monkey
 monkey.patch_socket()
@@ -39,16 +39,12 @@ class BetsApi(object):
     '''
 
     DEFAULT_SETTINGS = {
-        'bets_url': u'http://bets.42cc.co/v1.1.1/',
-        'timeout': 30,  # seconds
+        'bets_url': u'http://bets.42cc.co/v1.1.3/',
+        'timeout': 60,  # seconds
     }
 
-    bet_types_with_project = [
-        'budget',
-        'deadline',
-        '0_bugs',
-        'closed_tickets',
-    ]
+    ACTIVE_STATES = ['fresh', 'active', 'accept_end']
+    CLOSED_STATES = ['closed', 'executed', 'calculated', 'returned']
 
     TIME_FMT = '%Y-%m-%d %H:%M'
     DATE_FMT = '%Y-%m-%d'
@@ -104,6 +100,40 @@ class BetsApi(object):
 
         return bets
 
+    def get_bets(self, type=None, order_by=None, state=None, page=None, page_size=None):
+        """Return bets with given filters and ordering.
+
+        :param type: return bets only with this type.
+                     Use None to include all (default).
+        :param order_by: '-last_stake' or 'last_stake' to sort by stake's
+                         created date or None for default ordering.
+        :param state: one of 'active', 'closed', 'all' (default 'active').
+        :param page: default 1.
+        :param page_site: page size (default 100).
+        """
+        if page is None:
+            page = 1
+        if page_size is None:
+            page_size = 100
+        if state == 'all':
+            _states = []  # all states == no filter
+        elif state == 'closed':
+            _states = self.CLOSED_STATES
+        else:
+            _states = self.ACTIVE_STATES
+
+        url = urljoin(
+            self.settings['bets_url'],
+            'bets?page={}&page_size={}'.format(page, page_size))
+        url += '&state={}'.format(','.join(_states))
+        if type is not None:
+            url += '&type={}'.format(type)
+        if order_by in ['-last_stake', 'last_stake']:
+            url += '&order_by={}'.format(order_by)
+
+        res = self._req(url)
+        return res['bets']['results']
+
     def get_project_slug(self, bet):
         '''Return slug of a project that given bet is associated with
         or None if bet is not associated with any project.
@@ -144,10 +174,13 @@ class BetsApi(object):
             'bets?id=%s' % ','.join(ids))
         return self._req(url)['bets']['results']
 
-    def _create(self, url, data, expires_at, bets_until=None, min_stake=None):
+    def _create(self, url, data, expires_at, bets_until=None, min_stake=None,
+                group=None):
         url = urljoin(self.settings['bets_url'], url)
         data = data.copy()
         data['expires'] = expires_at.strftime(self.TIME_FMT)
+        if group is not None:
+            data['group'] = group
         if bets_until is not None:
             data['stakes_acception_end'] = bets_until.strftime(self.TIME_FMT)
         if min_stake is not None:
@@ -158,36 +191,47 @@ class BetsApi(object):
                  data['equal_3cp'], data['equal_4cp'], data['more_4cp']) = min_stake
         return self._req(url, 'POST', data=data)
 
-    def create_no_bugs(self, project_slug, expires_at, bets_until=None, min_stake=None):
+    def create_no_bugs(self, project_slug, expires_at, bets_until=None,
+                       min_stake=None, group=None):
         url = 'bet/create/no-bugs'
         data = {'project': project_slug}
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
+
+    def create_commit_bugs(self, project_slug, commit_hash, expires_at,
+                           bets_until=None, min_stake=None, group=None):
+        url = 'bet/create/commit_bug'
+        data = {
+            'project': project_slug,
+            'commit_hash': commit_hash,
+        }
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_budget(self, project_slug, expires_at, target_budget,
-                      bets_until=None, min_stake=None):
+                      bets_until=None, min_stake=None, group=None):
         url = 'bet/create/budget'
         data = {
             'project': project_slug,
             'goal': target_budget,
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_deadline(self, project_slug, expires_at, target_deadline,
-                        bets_until=None, min_stake=None):
+                        bets_until=None, min_stake=None, group=None):
         url = 'bet/create/deadline'
         data = {
             'project': project_slug,
             'goal': target_deadline.strftime(self.DATE_FMT),
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
-    def create_human(self, description, expires_at, bets_until=None, min_stake=None):
+    def create_human(self, description, expires_at, bets_until=None,
+                     min_stake=None, group=None):
         url = 'bet/create/human'
         data = {'description': description}
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_billable_hours(self, kava_username, expires_at, hours, start_date, end_date,
-                              bets_until=None, min_stake=None):
+                              bets_until=None, min_stake=None, group=None):
         url = 'bet/create/billable'
         data = {
             'user': kava_username,
@@ -195,10 +239,10 @@ class BetsApi(object):
             'start_date': start_date.strftime(self.DATE_FMT),
             'end_date': end_date.strftime(self.DATE_FMT),
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_closed_tickets(self, project_slug, expires_at, ticket_nums,
-                              bets_until=None, min_stake=None):
+                              bets_until=None, min_stake=None, group=None):
         url = 'bet/create/closed_tickets'
         if not isinstance(ticket_nums, list):
             ticket_nums = [ticket_nums]
@@ -206,43 +250,43 @@ class BetsApi(object):
             'project': project_slug,
             'tickets': ','.join(map(str, ticket_nums)),
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_fitting_budget(self, percent, expires_at, days=90,
-                              bets_until=None, min_stake=None):
+                              bets_until=None, min_stake=None, group=None):
         url = 'bet/create/fitting_budget'
         data = {
             'percent': percent,
             'last_N_days': days,
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_fitting_deadline(self, percent, expires_at, days=90,
-                                bets_until=None, min_stake=None):
+                                bets_until=None, min_stake=None, group=None):
         url = 'bet/create/fitting_deadline'
         data = {
             'percent': percent,
             'last_N_days': days,
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_without_defects(self, percent, expires_at, days=90,
-                               bets_until=None, min_stake=None):
+                               bets_until=None, min_stake=None, group=None):
         url = 'bet/create/without_defects'
         data = {
             'percent': percent,
             'last_N_days': days,
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def create_estimate_ticket(self, project_slug, expires_at, ticket_num,
-                               bets_until=None, min_stake=None):
+                               bets_until=None, min_stake=None, group=None):
         url = 'bet/create/estimate_ticket'
         data = {
             'project': project_slug,
             'ticket': ticket_num,
         }
-        return self._create(url, data, expires_at, bets_until, min_stake)
+        return self._create(url, data, expires_at, bets_until, min_stake, group)
 
     def set_callback(self, event, callback):
         '''Set callback for event.
